==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/es_AR.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Ejecute primero el asistente",
    "Add your profile information! For example your email is needed to reset your password." : "¡Agregue su información de perfil! Por ejemplo us correo electrónico es necesario para restablecer su contraseña.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Agregue su información de perfil! Establezca una imagen de perfil y nombre completo para reconocerlo más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a full name for easier recognition across all features." : "Agregue su información de perfil! Establezca su nombre completo para reconocerlo más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Agregue su información de perfil! Establezca una imagen de perfil para reconocerlo más fácilmente entre todas las funcionalidades. ",
    "Get the apps to sync your files" : "Obtenga las aplicaciones para sincronizar sus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Acceda & comparta sus archivos, calendarios, contactos, correo & más desde cualquier dispositivo, en sus términos",
    "Connect your desktop apps to %s" : "Conecte su aplicación de escritorio a %s",
    "Access files via WebDAV" : "Acceda a sus archivos vía WebDAV",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Puede encontrar más información en la <a target=\"_blank\" href=\"%s\">documentación</a> y en nuestro <a target=\"_blank\" href=\"%s\">sitio web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Si le agrada NextCloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud es un gran software abierto para sincronizar y compartir sus archivos. Puede obtenerlo de forma gratuita desde https://nextcloud.com\"> recomiéndelo a sus amigos</a> y <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribuya</a>!",
    "Connect your Calendar" : "Conectar su Calendario",
    "Connect your Contacts" : "Conecte sus Contactos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/es_AR.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Copiar al portapapeles",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "First run wizard" : "Ejecute primero el asistente",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Agregue su información de perfil! Establezca una imagen de perfil y nombre completo para reconocerlo más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a full name for easier recognition across all features." : "Agregue su información de perfil! Establezca su nombre completo para reconocerlo más fácilmente entre todas las funcionalidades. ",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Agregue su información de perfil! Establezca una imagen de perfil para reconocerlo más fácilmente entre todas las funcionalidades. ",
    "About" : "Acerca de",
    "Get the apps to sync your files" : "Obtenga las aplicaciones para sincronizar sus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "Connect your desktop apps to %s" : "Conecte su aplicación de escritorio a %s",
    "Access files via WebDAV" : "Acceda a sus archivos vía WebDAV",
    "A safe home for all your data" : "Un hogar seguro para todos tus datos.",
    "Server address" : "Dirección del servidor",
    "Copy link" : "Copiar enlace"
},
"nplurals=2; plural=(n != 1);");
